package es.ucm.fdi.grasia.faerie.container;

import es.ucm.fdi.grasia.faerie.core.ContextObserver;

/**
 * Lifecycle interface for the {@code ContextContainer} component. It provides methods to bind and unbind the
 * {@code ContextObserver}s to the context.
 * 
 * @author Chema
 * @see ContextObserver
 */
public interface ContextContainerService {

	/**
	 * Binds the specified {@code contextObserver} to the context.
	 * 
	 * @param contextObserver the {@code ContextObserver} to bind.
	 * @param properties the {@code ContextObserver} properties.
	 */
	public void bindContextObserver(ContextObserver contextObserver);

	/**
	 * Callback method used when the service is activated.
	 */
	public void activate();

	/**
	 * Callback method used when the service is deactivated.
	 */
	public void deactivate();

	/**
	 * Unbinds the specified {@code contextObserver} from the context.
	 * 
	 * @param contextObserver the {@code ContextObserver} to unbind.
	 * @param properties the {@code ContextObserver} properties.
	 */
	public void unbindContextObserver(ContextObserver contextObserver);
}
